// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "scene/Scene.hpp"
#include "prefabs/SimpleSpinningCubePrefab.hpp"
#include "prefabs/FPSLabel.hpp"
#include "scene/components/ui/UIImage.hpp"
#include "display/font/BitmapFont.hpp"

namespace Dawn {
  class HelloWorldScene : public Scene {
    protected:
      Camera *camera;
      SimpleSpinningCubePrefab *cube;
      UICanvas *canvas;
      UILabel *label;

      void stage() override {
        camera = Camera::create(this);
        camera->transform->lookAt(glm::vec3(3, 3, 3), glm::vec3(0, 0, 0));

        cube = SimpleSpinningCubePrefab::create(this);

        canvas = UICanvas::create(this);

        auto labelItem = FPSLabel::create(this);
        labelItem->transform.setParent(canvas->transform);
        labelItem->label->alignX = UI_COMPONENT_ALIGN_END;
        labelItem->label->alignment = glm::vec4(0, 0, 0, 0);
        labelItem->label->fontSize = 16;
      }
      
      std::vector<Asset*> getRequiredAssets() override {
        auto assMan = &this->game->assetManager;
        std::vector<Asset*> assets;
        vectorAppend(&assets, SimpleSpinningCubePrefab::getRequiredAssets(assMan));
        return assets;
      }

    public:
      HelloWorldScene(DawnGame *game) : Scene(game) {}
  };
}